django-siteblocks documentation
===============================

http://github.com/idlesign/django-siteblocks

*django-siteblocks is a reusable application for Django to build blocks of static or dynamic data that could be used in templates.*

It allows you to describe data that doesn't clearly belong to any application in your project in terms of static or dynamic blocks,
that could be rendered in certain places on site pages. These blocks are addressed in templates by their aliases.


Requirements
------------

.. image:: https://idlesign.github.io/lbc/py2-lbc.svg
   :target: https://idlesign.github.io/lbc/
   :alt: LBC Python 2

----

1. Python 2.7+ or 3.5+
2. Django 1.7+
3. Django Admin contrib enabled (optional)


Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    dynamic
    thirdparty


Get involved into django-siteblocks
-----------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do that at https://github.com/idlesign/django-siteblocks/issues

**Write code.** If you are eager to participate in application development, fork it at https://github.com/idlesign/django-siteblocks, write your code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Translate.** If want to translate the application into your native language use Transifex: https://www.transifex.com/projects/p/django-siteblocks/.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish them.


Also
----

If the application is not what you want for user registration, you might be interested in considering the other choices — https://www.djangopackages.com/grids/g/layout/
